@@ -161,10 +161,10 @@ class InlineKeyboardMarkup(BaseObject):
         self.inline_keyboard.clear()
 
     def as_dict(self):
-        return [[b.as_dict() for b in line] for line in self.inline_keyboard]
+        return {'inline_keyboard': [[b.as_dict() for b in line] for line in self.inline_keyboard]}
 
     def as_json(self):
-        return json.dumps(dict(inline_keyboard=self.as_dict()))
+        return json.dumps(self.as_dict())
 
 
 class KeyboardButton(BaseObject):
@@ -243,11 +243,24 @@ class ReplyKeyboardRemove(BaseObject):
 
 
 class Location(BaseObject):
-    __slots__ = ['longitude', 'latitude']
+    __slots__ = ['longitude', 'latitude', 'horizontal_accuracy', 'live_period', 'heading', 'proximity_alert_radius']
 
     def __init__(self, **kwargs):
         self.longitude = kwargs.get('longitude')
         self.latitude = kwargs.get('latitude')
+        self.horizontal_accuracy = kwargs.get('horizontal_accuracy')
+        self.live_period = kwargs.get('live_period')
+        self.heading = kwargs.get('heading')
+        self.proximity_alert_radius = kwargs.get('proximity_alert_radius')
+
+
+class ChatLocation(BaseObject):
+    __slots__ = ['location', 'address']
+    NESTED = ['location']
+
+    def __init__(self, **kwargs):
+        self.location = Location(**kwargs['location']) if 'location' in kwargs else None
+        self.address = kwargs.get('address')
 
 
 class PollOption(BaseObject):
@@ -270,8 +283,9 @@ class PollAnswer(BaseObject):
 
 class Poll(BaseObject):
     __slots__ = ['id', 'question', 'options', 'total_voter_count', 'is_closed', 'is_anonymous', 'type',
-                 'allows_multiple_answers', 'correct_option_id']
-    NESTED = ['options', ]
+                 'allows_multiple_answers', 'correct_option_id', 'explanation', 'explanation_entities', 'open_period',
+                 'close_date']
+    NESTED = ['options', 'explanation_entities']
 
     def __init__(self, **kwargs):
         self.id = kwargs.get('id')
@@ -283,12 +297,18 @@ class Poll(BaseObject):
         self.type = kwargs.get('type')
         self.allows_multiple_answers = kwargs.get('allows_multiple_answers')
         self.correct_option_id = kwargs.get('correct_option_id')
+        self.explanation = kwargs.get('explanation')
+        self.explanation_entities = [
+            MessageEntity(**v) for v in kwargs['explanation_entities']] if 'explanation_entities' in kwargs else list()
+        self.open_period = kwargs.get('open_period')
+        self.close_date = kwargs.get('close_date')
 
 
 class Dice(BaseObject):
-    __slots__ = ['value']
+    __slots__ = ['emoji', 'value']
 
     def __init__(self, **kwargs):
+        self.emoji = kwargs.get('emoji')
         self.value = kwargs.get('value')
 
 
@@ -300,6 +320,16 @@ class ResponseParameters(BaseObject):
         self.retry_after = kwargs.get('retry_after')
 
 
+class ProximityAlertTriggered(BaseObject):
+    __slots__ = ['traveler', 'watcher', 'distance']
+    NESTED = ['traveler', 'watcher']
+
+    def __init__(self, **kwargs):
+        self.traveler = User(**kwargs['traveler']) if 'traveler' in kwargs else None
+        self.watcher = User(**kwargs['watcher']) if 'watcher' in kwargs else None
+        self.distance = kwargs.get('distance')
+
+
 class UserProfilePhotos(BaseObject):
     __slots__ = ['total_count', 'photos']
     NESTED = ['photos', ]
@@ -310,7 +340,8 @@ class UserProfilePhotos(BaseObject):
 
 
 class Venue(BaseObject):
-    __slots__ = ['location', 'title', 'address', 'foursquare_id', 'foursquare_type']
+    __slots__ = ['location', 'title', 'address', 'foursquare_id', 'foursquare_type',
+                 'google_place_id', 'google_place_type']
     NESTED = ['location', ]
 
     def __init__(self, **kwargs):
@@ -319,10 +350,13 @@ class Venue(BaseObject):
         self.address = kwargs.get('address')
         self.foursquare_id = kwargs.get('foursquare_id')
         self.foursquare_type = kwargs.get('foursquare_type')
+        self.google_place_id = kwargs.get('google_place_id')
+        self.google_place_type = kwargs.get('google_place_type')
 
 
 class Video(BaseObject):
-    __slots__ = ['file_id', 'file_unique_id', 'width', 'height', 'duration', 'thumb', 'mime_type', 'file_size']
+    __slots__ = ['file_id', 'file_unique_id', 'width', 'height', 'duration', 'thumb',
+                 'file_name', 'mime_type', 'file_size']
     NESTED = ['thumb', ]
 
     def __init__(self, **kwargs):
@@ -332,6 +366,7 @@ class Video(BaseObject):
         self.height = kwargs.get('height')
         self.duration = kwargs.get('duration')
         self.thumb = PhotoSize(**kwargs['thumb']) if 'thumb' in kwargs else None
+        self.file_name = kwargs.get('file_name')
         self.mime_type = kwargs.get('mime_type')
         self.file_size = kwargs.get('file_size')
 
@@ -361,13 +396,14 @@ class Voice(BaseObject):
 
 
 class WebhookInfo(BaseObject):
-    __slots__ = ['url', 'has_custom_certificate', 'pending_update_count', 'last_error_date',
+    __slots__ = ['url', 'has_custom_certificate', 'pending_update_count', 'ip_address', 'last_error_date',
                  'last_error_message', 'max_connections', 'allowed_updates']
 
     def __init__(self, **kwargs):
         self.url = kwargs.get('url')
         self.has_custom_certificate = kwargs.get('has_custom_certificate')
         self.pending_update_count = kwargs.get('pending_update_count')
+        self.ip_address = kwargs.get('ip_address')
         self.last_error_date = kwargs.get('last_error_date')
         self.last_error_message = kwargs.get('last_error_message')
         self.max_connections = kwargs.get('max_connections')
@@ -392,7 +428,8 @@ class Animation(BaseObject):
 
 
 class Audio(BaseObject):
-    __slots__ = ['file_id', 'file_unique_id', 'duration', 'performer', 'title', 'mime_type', 'file_size', 'thumb']
+    __slots__ = ['file_id', 'file_unique_id', 'duration', 'performer', 'title', 'file_name',
+                 'mime_type', 'file_size', 'thumb']
     NESTED = ['thumb', ]
 
     def __init__(self, **kwargs):
@@ -401,6 +438,7 @@ class Audio(BaseObject):
         self.duration = kwargs.get('duration')
         self.performer = kwargs.get('performer')
         self.title = kwargs.get('title')
+        self.file_name = kwargs.get('file_name')
         self.mime_type = kwargs.get('mime_type')
         self.file_size = kwargs.get('file_size')
         self.thumb = PhotoSize(**kwargs['thumb']) if 'thumb' in kwargs else None
@@ -423,7 +461,7 @@ class User(BaseObject):
 
 
 class ChatMember(BaseObject):
-    __slots__ = ['user', 'status', 'custom_title', 'until_date', 'can_be_edited', 'can_change_info',
+    __slots__ = ['user', 'status', 'custom_title', 'is_anonymous' 'until_date', 'can_be_edited', 'can_change_info',
                  'can_post_messages', 'can_edit_messages', 'can_delete_messages', 'can_invite_users',
                  'can_restrict_members', 'can_pin_messages', 'can_promote_members', 'is_member', 'can_send_messages',
                  'can_send_media_messages', 'can_send_polls', 'can_send_other_messages', 'can_add_web_page_previews']
@@ -433,6 +471,7 @@ class ChatMember(BaseObject):
         self.user = User(**kwargs['user']) if 'user' in kwargs else None
         self.status = kwargs.get('status')
         self.custom_title = kwargs.get('custom_title')
+        self.is_anonymous = kwargs.get('is_anonymous')
         self.until_date = kwargs.get('until_date')
         self.can_be_edited = kwargs.get('can_be_edited')
         self.can_change_info = kwargs.get('can_change_info')
@@ -499,18 +538,21 @@ class InputFile(BaseObject):
 
 
 class InputMedia(BaseObject):
-    __slots__ = ['type', 'media', 'caption', 'parse_mode']
+    __slots__ = ['type', 'media', 'caption', 'parse_mode', 'caption_entities']
+    NESTED = ['caption_entities']
 
     def __init__(self, **kwargs):
         self.type = kwargs.get('type')
         self.media = kwargs.get('media')
         self.caption = kwargs.get('caption')
         self.parse_mode = kwargs.get('parse_mode')
+        self.caption_entities = [MessageEntity(**v) for v in
+                                 kwargs['caption_entities']] if 'caption_entities' in kwargs else list()
 
 
 class InputMediaAnimation(InputMedia):
-    __slots__ = ['type', 'media', 'caption', 'parse_mode', 'thumb', 'width', 'height', 'duration']
-    NESTED = ['thumb', ]
+    __slots__ = ['type', 'media', 'caption', 'parse_mode', 'caption_entities', 'thumb', 'width', 'height', 'duration']
+    NESTED = ['thumb', 'caption_entities']
 
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
@@ -522,8 +564,9 @@ class InputMediaAnimation(InputMedia):
 
 
 class InputMediaAudio(InputMedia):
-    __slots__ = ['type', 'media', 'caption', 'parse_mode', 'thumb', 'duration', 'performer', 'title']
-    NESTED = ['thumb', ]
+    __slots__ = ['type', 'media', 'caption', 'parse_mode', 'caption_entities', 'thumb', 'duration', 'performer',
+                 'title']
+    NESTED = ['thumb', 'caption_entities']
 
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
@@ -535,17 +578,19 @@ class InputMediaAudio(InputMedia):
 
 
 class InputMediaDocument(InputMedia):
-    __slots__ = ['type', 'media', 'caption', 'parse_mode', 'thumb']
-    NESTED = ['thumb', ]
+    __slots__ = ['type', 'media', 'caption', 'parse_mode', 'caption_entities', 'thumb',
+                 'disable_content_type_detection']
+    NESTED = ['thumb', 'caption_entities']
 
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
         self.type = 'document'
         self.thumb = InputFile(**kwargs['thumb']) if 'thumb' in kwargs else None
+        self.disable_content_type_detection = kwargs.get('disable_content_type_detection')
 
 
 class InputMediaPhoto(InputMedia):
-    __slots__ = ['type', 'media', 'caption', 'parse_mode']
+    __slots__ = ['type', 'media', 'caption', 'parse_mode', 'caption_entities']
 
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
@@ -553,8 +598,9 @@ class InputMediaPhoto(InputMedia):
 
 
 class InputMediaVideo(InputMedia):
-    __slots__ = ['type', 'media', 'caption', 'parse_mode', 'thumb', 'width', 'height', 'duration', 'supports_streaming']
-    NESTED = ['thumb', ]
+    __slots__ = ['type', 'media', 'caption', 'parse_mode', 'caption_entities', 'thumb', 'width', 'height', 'duration',
+                 'supports_streaming']
+    NESTED = ['thumb', 'caption_entities']
 
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
@@ -605,12 +651,15 @@ class InputContactMessageContent(InputMessageContent):
 
 
 class InputLocationMessageContent(InputMessageContent):
-    __slots__ = ['latitude', 'longitude', 'live_period']
+    __slots__ = ['latitude', 'longitude', 'live_period', 'horizontal_accuracy', 'heading', 'proximity_alert_radius']
 
     def __init__(self, **kwargs):
         self.latitude = kwargs.get('latitude')
         self.longitude = kwargs.get('longitude')
+        self.horizontal_accuracy = kwargs.get('horizontal_accuracy')
         self.live_period = kwargs.get('live_period')
+        self.heading = kwargs.get('heading')
+        self.proximity_alert_radius = kwargs.get('proximity_alert_radius')
 
 
 class InputTextMessageContent(InputMessageContent):
@@ -623,7 +672,8 @@ class InputTextMessageContent(InputMessageContent):
 
 
 class InputVenueMessageContent(InputMessageContent):
-    __slots__ = ['latitude', 'longitude', 'title', 'address', 'foursquare_id', 'foursquare_type']
+    __slots__ = ['latitude', 'longitude', 'title', 'address', 'foursquare_id', 'foursquare_type',
+                 'google_place_id', 'google_place_type']
 
     def __init__(self, **kwargs):
         self.latitude = kwargs.get('latitude')
@@ -632,6 +682,8 @@ class InputVenueMessageContent(InputMessageContent):
         self.address = kwargs.get('address')
         self.foursquare_id = kwargs.get('foursquare_id')
         self.foursquare_type = kwargs.get('foursquare_type')
+        self.google_place_id = kwargs.get('google_place_id')
+        self.google_place_type = kwargs.get('google_place_type')
 
 
 class ChosenInlineResult(BaseObject):
@@ -697,7 +749,7 @@ class InlineQueryResultArticle(InlineQueryResult):
 
 class InlineQueryResultAudio(InlineQueryResult):
     __slots__ = ['type', 'id', 'reply_markup', 'input_message_content', 'audio_url', 'parse_mode', 'title',
-                 'caption', 'performer', 'audio_duration']
+                 'caption', 'performer', 'audio_duration', 'caption_entities']
 
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
@@ -708,11 +760,13 @@ class InlineQueryResultAudio(InlineQueryResult):
         self.caption = kwargs.get('caption')
         self.performer = kwargs.get('performer')
         self.audio_duration = kwargs.get('audio_duration')
+        self.caption_entities = [MessageEntity(**v) for v in
+                                 kwargs['caption_entities']] if 'caption_entities' in kwargs else list()
 
 
 class InlineQueryResultCachedAudio(InlineQueryResult):
     __slots__ = ['type', 'id', 'reply_markup', 'input_message_content',
-                 'audio_file_id', 'caption', 'parse_mode']
+                 'audio_file_id', 'caption', 'parse_mode', 'caption_entities']
 
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
@@ -720,10 +774,12 @@ class InlineQueryResultCachedAudio(InlineQueryResult):
         self.audio_file_id = kwargs.get('audio_file_id')
         self.caption = kwargs.get('caption')
         self.parse_mode = kwargs.get('parse_mode')
+        self.caption_entities = [MessageEntity(**v) for v in
+                                 kwargs['caption_entities']] if 'caption_entities' in kwargs else list()
 
 
 class InlineQueryResultCachedDocument(InlineQueryResult):
-    __slots__ = ['type', 'id', 'reply_markup', 'input_message_content',
+    __slots__ = ['type', 'id', 'reply_markup', 'input_message_content', 'caption_entities',
                  'title', 'document_file_id', 'description', 'caption', 'parse_mode']
 
     def __init__(self, **kwargs):
@@ -734,10 +790,13 @@ class InlineQueryResultCachedDocument(InlineQueryResult):
         self.description = kwargs.get('description')
         self.caption = kwargs.get('caption')
         self.parse_mode = kwargs.get('parse_mode')
+        self.caption_entities = [MessageEntity(**v) for v in
+                                 kwargs['caption_entities']] if 'caption_entities' in kwargs else list()
 
 
 class InlineQueryResultCachedGif(InlineQueryResult):
-    __slots__ = ['type', 'id', 'reply_markup', 'input_message_content', 'gif_file_id', 'title', 'caption', 'parse_mode']
+    __slots__ = ['type', 'id', 'reply_markup', 'input_message_content', 'gif_file_id', 'title', 'caption', 'parse_mode',
+                 'caption_entities']
 
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
@@ -746,11 +805,13 @@ class InlineQueryResultCachedGif(InlineQueryResult):
         self.title = kwargs.get('title')
         self.caption = kwargs.get('caption')
         self.parse_mode = kwargs.get('parse_mode')
+        self.caption_entities = [MessageEntity(**v) for v in
+                                 kwargs['caption_entities']] if 'caption_entities' in kwargs else list()
 
 
 class InlineQueryResultCachedMpeg4Gif(InlineQueryResult):
     __slots__ = ['type', 'id', 'reply_markup', 'input_message_content',
-                 'mpeg4_file_id', 'title', 'caption', 'parse_mode']
+                 'mpeg4_file_id', 'title', 'caption', 'parse_mode', 'caption_entities']
 
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
@@ -759,10 +820,12 @@ class InlineQueryResultCachedMpeg4Gif(InlineQueryResult):
         self.title = kwargs.get('title')
         self.caption = kwargs.get('caption')
         self.parse_mode = kwargs.get('parse_mode')
+        self.caption_entities = [MessageEntity(**v) for v in
+                                 kwargs['caption_entities']] if 'caption_entities' in kwargs else list()
 
 
 class InlineQueryResultCachedPhoto(InlineQueryResult):
-    __slots__ = ['type', 'id', 'reply_markup', 'input_message_content',
+    __slots__ = ['type', 'id', 'reply_markup', 'input_message_content', 'caption_entities',
                  'photo_file_id', 'title', 'description', 'caption', 'parse_mode']
 
     def __init__(self, **kwargs):
@@ -773,6 +836,8 @@ class InlineQueryResultCachedPhoto(InlineQueryResult):
         self.description = kwargs.get('description')
         self.caption = kwargs.get('caption')
         self.parse_mode = kwargs.get('parse_mode')
+        self.caption_entities = [MessageEntity(**v) for v in
+                                 kwargs['caption_entities']] if 'caption_entities' in kwargs else list()
 
 
 class InlineQueryResultCachedSticker(InlineQueryResult):
@@ -786,7 +851,7 @@ class InlineQueryResultCachedSticker(InlineQueryResult):
 
 class InlineQueryResultCachedVideo(InlineQueryResult):
     __slots__ = ['type', 'id', 'reply_markup', 'input_message_content', 'video_file_id', 'title', 'description',
-                 'caption', 'parse_mode']
+                 'caption', 'parse_mode', 'caption_entities']
 
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
@@ -796,11 +861,13 @@ class InlineQueryResultCachedVideo(InlineQueryResult):
         self.description = kwargs.get('description')
         self.caption = kwargs.get('caption')
         self.parse_mode = kwargs.get('parse_mode')
+        self.caption_entities = [MessageEntity(**v) for v in
+                                 kwargs['caption_entities']] if 'caption_entities' in kwargs else list()
 
 
 class InlineQueryResultCachedVoice(InlineQueryResult):
     __slots__ = ['type', 'id', 'reply_markup', 'input_message_content', 'voice_file_id',
-                 'title', 'caption', 'parse_mode']
+                 'title', 'caption', 'parse_mode', 'caption_entities']
 
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
@@ -809,6 +876,8 @@ class InlineQueryResultCachedVoice(InlineQueryResult):
         self.title = kwargs.get('title')
         self.caption = kwargs.get('caption')
         self.parse_mode = kwargs.get('parse_mode')
+        self.caption_entities = [MessageEntity(**v) for v in
+                                 kwargs['caption_entities']] if 'caption_entities' in kwargs else list()
 
 
 class InlineQueryResultContact(InlineQueryResult):
@@ -829,7 +898,8 @@ class InlineQueryResultContact(InlineQueryResult):
 
 class InlineQueryResultDocument(InlineQueryResult):
     __slots__ = ['type', 'id', 'reply_markup', 'input_message_content', 'title', 'caption', 'parse_mode',
-                 'document_url', 'mime_type', 'description', 'thumb_url', 'thumb_width', 'thumb_height']
+                 'document_url', 'mime_type', 'description', 'thumb_url', 'thumb_width', 'thumb_height',
+                 'caption_entities']
 
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
@@ -843,6 +913,8 @@ class InlineQueryResultDocument(InlineQueryResult):
         self.thumb_url = kwargs.get('thumb_url')
         self.thumb_width = kwargs.get('thumb_width')
         self.thumb_height = kwargs.get('thumb_height')
+        self.caption_entities = [MessageEntity(**v) for v in
+                                 kwargs['caption_entities']] if 'caption_entities' in kwargs else list()
 
 
 class InlineQueryResultGame(InlineQueryResult):
@@ -857,7 +929,7 @@ class InlineQueryResultGame(InlineQueryResult):
 
 class InlineQueryResultGif(InlineQueryResult):
     __slots__ = ['type', 'id', 'reply_markup', 'input_message_content', 'gif_url', 'gif_width', 'gif_height',
-                 'gif_duration', 'thumb_url', 'title', 'caption', 'parse_mode']
+                 'gif_duration', 'thumb_url', 'thumb_mime_type', 'title', 'caption', 'parse_mode', 'caption_entities']
 
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
@@ -867,14 +939,18 @@ class InlineQueryResultGif(InlineQueryResult):
         self.gif_height = kwargs.get('gif_height')
         self.gif_duration = kwargs.get('gif_duration')
         self.thumb_url = kwargs.get('thumb_url')
+        self.thumb_mime_type = kwargs.get('thumb_mime_type')
         self.title = kwargs.get('title')
         self.caption = kwargs.get('caption')
         self.parse_mode = kwargs.get('parse_mode')
+        self.caption_entities = [MessageEntity(**v) for v in
+                                 kwargs['caption_entities']] if 'caption_entities' in kwargs else list()
 
 
 class InlineQueryResultLocation(InlineQueryResult):
     __slots__ = ['type', 'id', 'reply_markup', 'input_message_content', 'latitude', 'longitude', 'title',
-                 'live_period', 'thumb_url', 'thumb_width', 'thumb_height']
+                 'live_period', 'thumb_url', 'thumb_width', 'thumb_height', 'horizontal_accuracy', 'heading',
+                 'proximity_alert_radius']
 
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
@@ -882,15 +958,18 @@ class InlineQueryResultLocation(InlineQueryResult):
         self.latitude = kwargs.get('latitude')
         self.longitude = kwargs.get('longitude')
         self.title = kwargs.get('title')
+        self.horizontal_accuracy = kwargs.get('horizontal_accuracy')
         self.live_period = kwargs.get('live_period')
+        self.heading = kwargs.get('heading')
+        self.proximity_alert_radius = kwargs.get('proximity_alert_radius')
         self.thumb_url = kwargs.get('thumb_url')
         self.thumb_width = kwargs.get('thumb_width')
         self.thumb_height = kwargs.get('thumb_height')
 
 
 class InlineQueryResultMpeg4Gif(InlineQueryResult):
-    __slots__ = ['type', 'id', 'reply_markup', 'input_message_content', 'mpeg4_url', 'mpeg4_width',
-                 'mpeg4_height', 'mpeg4_duration', 'thumb_url', 'title', 'caption', 'parse_mode']
+    __slots__ = ['type', 'id', 'reply_markup', 'input_message_content', 'mpeg4_url', 'mpeg4_width', 'mpeg4_height',
+                 'mpeg4_duration', 'thumb_url', 'thumb_mime_type', 'title', 'caption', 'parse_mode', 'caption_entities']
 
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
@@ -900,14 +979,17 @@ class InlineQueryResultMpeg4Gif(InlineQueryResult):
         self.mpeg4_height = kwargs.get('mpeg4_height')
         self.mpeg4_duration = kwargs.get('mpeg4_duration')
         self.thumb_url = kwargs.get('thumb_url')
+        self.thumb_mime_type = kwargs.get('thumb_mime_type')
         self.title = kwargs.get('title')
         self.caption = kwargs.get('caption')
         self.parse_mode = kwargs.get('parse_mode')
+        self.caption_entities = [MessageEntity(**v) for v in
+                                 kwargs['caption_entities']] if 'caption_entities' in kwargs else list()
 
 
 class InlineQueryResultPhoto(InlineQueryResult):
     __slots__ = ['type', 'id', 'reply_markup', 'input_message_content', 'photo_url', 'thumb_url',
-                 'photo_width', 'photo_height', 'title', 'description', 'caption', 'parse_mode']
+                 'photo_width', 'photo_height', 'title', 'description', 'caption', 'parse_mode', 'caption_entities']
 
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
@@ -920,11 +1002,14 @@ class InlineQueryResultPhoto(InlineQueryResult):
         self.description = kwargs.get('description')
         self.caption = kwargs.get('caption')
         self.parse_mode = kwargs.get('parse_mode')
+        self.caption_entities = [MessageEntity(**v) for v in
+                                 kwargs['caption_entities']] if 'caption_entities' in kwargs else list()
 
 
 class InlineQueryResultVenue(InlineQueryResult):
     __slots__ = ['type', 'id', 'reply_markup', 'input_message_content', 'latitude', 'longitude', 'title',
-                 'address', 'foursquare_id', 'foursquare_type', 'thumb_url', 'thumb_width', 'thumb_height']
+                 'address', 'foursquare_id', 'foursquare_type', 'thumb_url', 'thumb_width', 'thumb_height',
+                 'google_place_id', 'google_place_type']
 
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
@@ -935,6 +1020,8 @@ class InlineQueryResultVenue(InlineQueryResult):
         self.address = kwargs.get('address')
         self.foursquare_id = kwargs.get('foursquare_id')
         self.foursquare_type = kwargs.get('foursquare_type')
+        self.google_place_id = kwargs.get('google_place_id')
+        self.google_place_type = kwargs.get('google_place_type')
         self.thumb_url = kwargs.get('thumb_url')
         self.thumb_width = kwargs.get('thumb_width')
         self.thumb_height = kwargs.get('thumb_height')
@@ -942,7 +1029,8 @@ class InlineQueryResultVenue(InlineQueryResult):
 
 class InlineQueryResultVideo(InlineQueryResult):
     __slots__ = ['type', 'id', 'reply_markup', 'input_message_content', 'video_url', 'mime_type', 'thumb_url',
-                 'title', 'caption', 'parse_mode', 'video_width', 'video_height', 'video_duration', 'description']
+                 'title', 'caption', 'parse_mode', 'video_width', 'video_height', 'video_duration', 'description',
+                 'caption_entities']
 
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
@@ -957,11 +1045,13 @@ class InlineQueryResultVideo(InlineQueryResult):
         self.video_height = kwargs.get('video_height')
         self.video_duration = kwargs.get('video_duration')
         self.description = kwargs.get('description')
+        self.caption_entities = [MessageEntity(**v) for v in
+                                 kwargs['caption_entities']] if 'caption_entities' in kwargs else list()
 
 
 class InlineQueryResultVoice(InlineQueryResult):
     __slots__ = ['type', 'id', 'reply_markup', 'input_message_content', 'voice_url', 'title', 'caption',
-                 'parse_mode', 'voice_duration']
+                 'parse_mode', 'voice_duration', 'caption_entities']
 
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
@@ -971,6 +1061,8 @@ class InlineQueryResultVoice(InlineQueryResult):
         self.caption = kwargs.get('caption')
         self.parse_mode = kwargs.get('parse_mode')
         self.voice_duration = kwargs.get('voice_duration')
+        self.caption_entities = [MessageEntity(**v) for v in
+                                 kwargs['caption_entities']] if 'caption_entities' in kwargs else list()
 
 
 class BaseElementError(BaseObject):
@@ -1260,8 +1352,9 @@ class BotCommand(BaseObject):
 
 class Chat(BaseObject):
     __slots__ = ['id', 'type', 'title', 'username', 'first_name', 'last_name', 'photo', 'description', 'invite_link',
-                 'pinned_message', 'permissions', 'slow_mode_delay', 'sticker_set_name', 'can_set_sticker_set']
-    NESTED = ['photo', 'pinned_message', 'permissions']
+                 'pinned_message', 'permissions', 'slow_mode_delay', 'sticker_set_name', 'can_set_sticker_set',
+                 'location']
+    NESTED = ['photo', 'pinned_message', 'permissions', 'location']
 
     def __init__(self, **kwargs):
         self.id = kwargs.get('id')
@@ -1278,25 +1371,29 @@ class Chat(BaseObject):
         self.slow_mode_delay = kwargs.get('slow_mode_delay')
         self.sticker_set_name = kwargs.get('sticker_set_name')
         self.can_set_sticker_set = kwargs.get('can_set_sticker_set')
+        self.location = ChatLocation(**kwargs['location']) if 'location' in kwargs else None
 
 
 class Message(BaseObject):
-    __slots__ = ['message_id', 'from_', 'date', 'chat', 'forward_from_chat', 'forward_from', 'forward_signature',
-                 'forward_sender_name', 'forward_date', 'reply_to_message', 'edit_date', 'media_group_id',
-                 'author_signature', 'text', 'entities', 'caption_entities', 'audio', 'document', 'animation',
-                 'game', 'photo', 'sticker', 'video', 'voice', 'video_note', 'caption', 'contact', 'location',
-                 'venue', 'poll', 'dice', 'new_chat_members', 'left_chat_member', 'new_chat_title', 'new_chat_photo',
-                 'delete_chat_photo', 'group_chat_created', 'supergroup_chat_created', 'channel_chat_created',
-                 'migrate_to_chat_id', 'migrate_from_chat_id', 'pinned_message', 'invoice',
-                 'successful_payment', 'connected_website', 'passport_data', 'reply_markup']
-    NESTED = ['from_', 'chat', 'forward_from_chat', 'forward_from', 'reply_to_message', 'entities', 'caption_entities',
-              'audio', 'document', 'animation', 'game', 'photo', 'sticker', 'video', 'voice', 'video_note', 'contact',
-              'location', 'venue', 'poll', 'dice', 'new_chat_members', 'left_chat_member', 'new_chat_photo',
-              'pinned_message', 'invoice', 'successful_payment', 'passport_data', 'reply_markup']
+    __slots__ = ['message_id', 'from_', 'sender_chat', 'date', 'chat', 'forward_from_chat', 'forward_from',
+                 'forward_signature', 'forward_sender_name', 'forward_date', 'reply_to_message', 'via_bot',
+                 'edit_date', 'media_group_id', 'author_signature', 'text', 'entities', 'caption_entities',
+                 'audio', 'document', 'animation', 'game', 'photo', 'sticker', 'video', 'voice', 'video_note',
+                 'caption', 'contact', 'location', 'venue', 'poll', 'dice', 'new_chat_members', 'left_chat_member',
+                 'new_chat_title', 'new_chat_photo', 'delete_chat_photo', 'group_chat_created',
+                 'supergroup_chat_created', 'channel_chat_created', 'migrate_to_chat_id', 'migrate_from_chat_id',
+                 'pinned_message', 'invoice', 'successful_payment', 'connected_website', 'passport_data',
+                 'proximity_alert_triggered', 'reply_markup']
+    NESTED = ['from_', 'sender_chat', 'chat', 'forward_from_chat', 'forward_from', 'reply_to_message', 'via_bot',
+              'entities', 'caption_entities', 'audio', 'document', 'animation', 'game', 'photo', 'sticker', 'video',
+              'voice', 'video_note', 'contact', 'location', 'venue', 'poll', 'dice', 'new_chat_members',
+              'left_chat_member', 'new_chat_photo', 'pinned_message', 'invoice', 'successful_payment', 'passport_data',
+              'proximity_alert_triggered', 'reply_markup']
 
     def __init__(self, **kwargs):
         self.message_id = kwargs.get('message_id')
         self.from_ = User(**kwargs['from']) if 'from' in kwargs else None
+        self.sender_chat = Chat(**kwargs['sender_chat']) if 'sender_chat' in kwargs else None
         self.date = kwargs.get('date')
         self.chat = Chat(**kwargs['chat']) if 'chat' in kwargs else None
         self.forward_from_chat = Chat(**kwargs['forward_from_chat']) if 'forward_from_chat' in kwargs else None
@@ -1305,6 +1402,7 @@ class Message(BaseObject):
         self.forward_sender_name = kwargs.get('forward_sender_name')
         self.forward_date = kwargs.get('forward_date')
         self.reply_to_message = Message(**kwargs['reply_to_message']) if 'reply_to_message' in kwargs else None
+        self.via_bot = User(**kwargs['via_bot']) if 'via_bot' in kwargs else None
         self.edit_date = kwargs.get('edit_date')
         self.media_group_id = kwargs.get('media_group_id')
         self.author_signature = kwargs.get('author_signature')
@@ -1345,6 +1443,8 @@ class Message(BaseObject):
             **kwargs['successful_payment']) if 'successful_payment' in kwargs else None
         self.connected_website = kwargs.get('connected_website')
         self.passport_data = PassportData(**kwargs['passport_data']) if 'passport_data' in kwargs else None
+        self.proximity_alert_triggered = ProximityAlertTriggered(
+            **kwargs['proximity_alert_triggered']) if 'proximity_alert_triggered' in kwargs else None
         self.reply_markup = InlineKeyboardMarkup(**kwargs['reply_markup']) if 'reply_markup' in kwargs else None
 
 
@@ -1384,4 +1484,4 @@ class Update(BaseObject):
         self.pre_checkout_query = PreCheckoutQuery(
             **kwargs['pre_checkout_query']) if 'pre_checkout_query' in kwargs else None
         self.poll = Poll(**kwargs['poll']) if 'poll' in kwargs else None
-        self.poll_answer = PollAnswer(**kwargs['poll_answer']) if 'poll_answer' in kwargs else None
\ No newline at end of file
+        self.poll_answer = PollAnswer(**kwargs['poll_answer']) if 'poll_answer' in kwargs else None
